@@ -178,18 +178,16 @@ def plotStereographicProjection(userListOfStars=[],
 								displayDeclinationNumbers=True,
 								incrementBy=10,
 								isPrecessionIncluded=True,
+								showPlot=True,
 								fig_plot_title=None,
 								fig_plot_color="C0",
 								figsize_n=12,
 								figsize_dpi=100,
 								save_plot_name=None):
-	# plot star chart as a circular graph
-	list_of_stars = getStarList(userListOfStars)
-
-	# Convert Star chart from RA hours to Radians to chart
-	list_of_stars = convertRAhrtoRadians(list_of_stars)
 
 	# Catch errors in given arguments before plotting and set default constants
+	userListOfStars = [x.title() for x in userListOfStars] # convert all names to capitalized
+	northOrSouth = northOrSouth.capitalize()
 	star_chart_spherical_projection.errorHandling(userListOfStars, 
 													northOrSouth, 
 													declination_min,
@@ -198,12 +196,18 @@ def plotStereographicProjection(userListOfStars=[],
 													displayDeclinationNumbers,
 													incrementBy, 
 													isPrecessionIncluded,
+													showPlot,
 													fig_plot_title,
 													fig_plot_color,
 													figsize_n,
 													figsize_dpi,
 													save_plot_name)
-	northOrSouth = northOrSouth.capitalize()
+
+	# plot star chart as a circular graph
+	list_of_stars = getStarList(userListOfStars)
+
+	# Convert Star chart from RA hours to Radians to chart
+	list_of_stars = convertRAhrtoRadians(list_of_stars)
 
 	# Set max declination based on hemisphere selected
 	if declination_min is None:
@@ -222,6 +226,7 @@ def plotStereographicProjection(userListOfStars=[],
 	logger.debug("displayDeclinationNumbers = {0}".format(displayDeclinationNumbers))
 	logger.debug("incrementBy = {0}".format(incrementBy))
 	logger.debug("isPrecessionIncluded = {0}".format(isPrecessionIncluded))
+	logger.debug("showPlot = {0}".format(showPlot))
 	logger.debug("fig_plot_title = {0}".format(fig_plot_title))
 	logger.debug("fig_plot_color = {0}".format(fig_plot_color))
 	logger.debug("figsize_n = {0}".format(figsize_n))
@@ -379,4 +384,5 @@ def plotStereographicProjection(userListOfStars=[],
 	if save_plot_name is not None: 
 		fig.savefig(save_plot_name)
 
-	plt.show()
+	if showPlot:
+		plt.show()
